<?php
/**
 * Template part for displaying posts in loop
 *
 * @package UnfinityPlus
 */
$post_author_on = unfinityplus_get_opt( 'post_author_on', true );
$post_author_info = unfinityplus_get_opt( 'post_author_info', false );
$post_categories_on = unfinityplus_get_opt( 'post_categories_on', true );
$post_comments_on = unfinityplus_get_opt( 'post_comments_on', true );
$post_date_on = unfinityplus_get_opt( 'post_date_on', false );
$post_social_share_on = unfinityplus_get_opt( 'post_social_share_on', false );
$post_feature_image_on = unfinityplus_get_opt( 'post_feature_image_on', true );
?>
<article id="post-<?php the_ID(); ?>" <?php post_class('single-hentry'); ?>>
    <div class="entry-header">
        <h2 class="entry-title"><?php the_title(); ?></h2>
        <?php if($post_author_on) : ?>
            <ul class="entry-meta">
                <?php if($post_author_on) : ?>
                    <li class="item-author">
                        <span><?php echo esc_html__('by:', 'unfinityplus'); ?></span>
                        <?php the_author_posts_link(); ?>
                    </li>
                <?php endif; ?>
            </ul>
        <?php endif; ?>
    </div>
    <?php if (has_post_format('gallery')) : ?>
        <div class="entry-featured entry-gallery">
            <?php
            $light_box = unfinityplus_get_post_format_value('post-gallery-lightbox', '0');
            $gallery_list = explode(',', unfinityplus_get_post_format_value('post-gallery-images', ''));
            if (class_exists('ReduxFramework')) : 
                wp_enqueue_script( 'owl-carousel' );
                wp_enqueue_script( 'unfinityplus-carousel' );
                ?>
                <div class="ct-carousel owl-carousel featured-active <?php if($light_box) {echo 'images-light-box';} ?>" data-item-xs="1" data-item-sm="1" data-item-md="1" data-item-lg="1" data-margin="30" data-loop="true" data-autoplay="false" data-autoplaytimeout="5000" data-smartspeed="250" data-center="false" data-arrows="true" data-bullets="false" data-stagepadding="0" data-stagepaddingsm="0" data-rtl="false">
                    <?php
                    foreach ($gallery_list as $img_id):
                        ?>
                        <div class="ct-carousel-item">
                            <a class="light-box" href="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'full'));?>"><img src="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'large'));?>" alt="<?php echo esc_attr(get_post_meta( $img_id, '_wp_attachment_image_alt', true )) ?>"></a>
                        </div>
                        <?php
                    endforeach;
                    ?>
                </div>
            <?php endif; ?>
        </div>
    <?php elseif (has_post_format('quote')) : ?>
        <div class="entry-featured">
            <?php
                $quote_text = unfinityplus_get_post_format_value('post-quote-cite', '');
                echo esc_attr($quote_text);
            ?>
        </div>
    <?php elseif (has_post_format('link')) : ?>
        <div class="entry-featured">
            <?php
                $link_pf = unfinityplus_get_post_format_value('post-link-url', '#');
                echo esc_url($link_pf);
            ?>
        </div>
    <?php elseif (has_post_format('video')) : ?>
        <div class="entry-featured">
            <div class="entry-video featured-active">
                <?php
                $video_url = unfinityplus_get_post_format_value('post-video-url', '#');
                $video_file = unfinityplus_get_post_format_value('post-video-file', '');
                $video_html = unfinityplus_get_post_format_value('post-video-html', '');
                $video = '';
                if (!empty($video_url)) {
                    global $wp_embed;
                    echo ' '.$wp_embed->run_shortcode('[embed]' . $video_url . '[/embed]');
                } elseif (!empty($video_file)) {
                    if (strpos('[embed', $video_file)) {
                        global $wp_embed;
                        echo esc_html($wp_embed->run_shortcode($video_file));
                    } else {
                        echo do_shortcode($video_file);
                    }
                } else {
                    if ('' != $video_html) {
                        echo esc_html($video_html);
                    }
                }
                ?>
            </div>
        </div>
    <?php elseif (has_post_format('audio')) : ?>
        <div class="entry-featured">
            <?php
                $audio_url = unfinityplus_get_post_format_value('post-audio-url', '#');
                echo esc_url($audio_url);
            ?>
        </div>
    <?php else :
        if (has_post_thumbnail() && $post_feature_image_on ) {
            echo '<div class="entry-featured"><div class="post-image">'; ?>
                <?php the_post_thumbnail('large'); ?>
            <?php echo '</div></div>';
        } ?>
    <?php endif; ?>
    <div class="entry-body">
        <?php if($post_comments_on || $post_categories_on || $post_date_on) : ?>
            <ul class="entry-meta">
                <li class="item-time"><?php echo human_time_diff( get_the_time('U'), current_time('timestamp') ) . ' ago'; ?></li>
                <?php if($post_categories_on) : ?>
                    <li class="item-category"><i class="fa fa-tag"></i><?php the_terms( get_the_ID(), 'category', '', ', ' ); ?></li>
                <?php endif; ?>
                <?php if($post_comments_on) : ?>
                    <li><i class="fa fa-comments"></i><a href="<?php the_permalink(); ?>"><?php echo comments_number(esc_html__('No Comments', 'unfinityplus'),esc_html__('Comment 1', 'unfinityplus'),esc_html__('% Comments', 'unfinityplus')); ?></a></li>
                <?php endif; ?>
                <?php if($post_date_on) : ?>
                    <li><i class="fa fa-calendar"></i><?php echo get_the_date(); ?></li>
                <?php endif; ?>
                <?php if(is_sticky()) { ?>
                    <li><i class="fa fa-thumb-tack"></i><?php echo esc_html__('Sticky', 'unfinityplus'); ?></li>
                <?php } ?>
            </ul>
        <?php endif; ?>
        <div class="entry-content clearfix">
            <?php
                the_content();
                wp_link_pages( array(
                    'before'      => '<div class="page-links">',
                    'after'       => '</div>',
                    'link_before' => '<span>',
                    'link_after'  => '</span>',
                ) );
            ?>
        </div><!-- .entry-content -->
        <?php if($post_social_share_on) : ?>
            <div class="content-social-wrap">
                <?php if($post_social_share_on) :
                    unfinityplus_socials_share_default(); 
                endif; ?>
            </div>
        <?php endif; ?>
        <?php if($post_author_info) : ?>
            <div class="entry-author-info">
                <div class="author-post clearfix">
                    <div class="author-avatar">
                            <?php echo get_avatar( get_the_author_meta( 'ID' ), 'full' ); ?>
                        </div>
                    <div class="author-description">
                        <span><?php echo get_the_author(); ?></span>
                        <p>
                            <?php the_author_meta( 'description' ); ?>
                        </p>
                        <?php unfinityplus_get_user_social(); ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    </div>
</article><!-- #post -->